@@ -9,7 +9,7 @@ CREATE TABLE "users" (
     "last_login" timestamp with time zone DEFAULT NULL,
     "failed_login" timestamp with time zone DEFAULT NULL,
     "failed_login_counter" integer DEFAULT NULL,
-    "language" varchar(5),
+    "language" varchar(16),
     "preferences" long DEFAULT NULL,
     CONSTRAINT "users_username_key" UNIQUE ("username", "mail_host")
 );
@@ -63,6 +63,53 @@ BEGIN
 END;
 /
 
+
+CREATE TABLE "responses" (
+    "response_id" integer PRIMARY KEY,
+    "user_id" integer NOT NULL
+        REFERENCES "users" ("user_id") ON DELETE CASCADE,
+    "changed" timestamp with time zone DEFAULT current_timestamp NOT NULL,
+    "del" smallint DEFAULT 0 NOT NULL,
+    "name" varchar(128) NOT NULL,
+    "data" long NOT NULL,
+    "is_html" smallint DEFAULT 0 NOT NULL
+);
+
+CREATE INDEX "responses_user_id_idx" ON "responses" ("user_id", "del");
+
+CREATE SEQUENCE "responses_seq"
+    START WITH 1 INCREMENT BY 1 NOMAXVALUE;
+
+CREATE TRIGGER "responses_seq_trig"
+BEFORE INSERT ON "responses" FOR EACH ROW
+BEGIN
+    :NEW."response_id" := "response_seq".nextval;
+END;
+/
+
+
+CREATE TABLE "collected_addresses" (
+    "address_id" integer PRIMARY KEY,
+    "user_id" integer NOT NULL
+        REFERENCES "users" ("user_id") ON DELETE CASCADE,
+    "changed" timestamp with time zone DEFAULT current_timestamp NOT NULL,
+    "name" varchar(255) DEFAULT NULL,
+    "email" varchar(255) DEFAULT NULL,
+    "type" integer NOT NULL
+);
+
+CREATE UNIQUE INDEX "collected_addresses_user_id_idx" ON "collected_addresses" ("user_id", "type", "email");
+
+CREATE SEQUENCE "collected_addresses_seq"
+    START WITH 1 INCREMENT BY 1 NOMAXVALUE;
+
+CREATE TRIGGER "collected_addresses_seq_trig"
+BEFORE INSERT ON "collected_addresses" FOR EACH ROW
+BEGIN
+    :NEW."address_id" := "collected_addresses_seq".nextval;
+END;
+/
+
 CREATE TABLE "contacts" (
     "contact_id" integer PRIMARY KEY,
     "user_id" integer NOT NULL
@@ -186,7 +233,7 @@ CREATE INDEX "cache_messages_expires_idx" ON "cache_messages" ("expires");
 CREATE TABLE "dictionary" (
     "user_id" integer DEFAULT NULL
         REFERENCES "users" ("user_id") ON DELETE CASCADE,
-    "language" varchar(5) NOT NULL,
+    "language" varchar(16) NOT NULL,
     "data" long DEFAULT NULL,
     CONSTRAINT "dictionary_user_id_lang_key" UNIQUE ("user_id", "language")
 );
@@ -238,4 +285,4 @@ CREATE TABLE "system" (
     "value" long
 );
 
-INSERT INTO "system" ("name", "value") VALUES ('roundcube-version', '2019092900');
+INSERT INTO "system" ("name", "value") VALUES ('roundcube-version', '2021100300');
