@@ -117,7 +117,7 @@ rcube_webmail.prototype.enigma_key_import = function()
     this.enigma_import_dialog = this.simple_dialog(dialog, this.gettext('enigma.importkeys'), import_func, {
         button: 'import',
         width: 500,
-        height: 150
+        height: 180
     });
 };
 
@@ -156,7 +156,7 @@ rcube_webmail.prototype.enigma_key_create_save = function()
     var options, lock, users = [],
         password = $('#key-pass').val(),
         confirm = $('#key-pass-confirm').val(),
-        size = $('#key-size').val();
+        type = $('#key-type').val();
 
     $('[name="identity[]"]:checked').each(function() {
         users.push({name: $(this).data('name') || '', email: $(this).data('email')});
@@ -180,18 +180,29 @@ rcube_webmail.prototype.enigma_key_create_save = function()
 
     // generate keys
     // use OpenPGP.js if browser supports required features
-    if (window.openpgp && (window.msCrypto || (window.crypto && (window.crypto.getRandomValues || window.crypto.subtle)))) {
+    if (window.openpgp && window.crypto && window.crypto.getRandomValues) {
         lock = this.set_busy(true, 'enigma.keygenerating');
         options = {
-            numBits: size,
-            userIds: users,
-            passphrase: password
+            userIDs: users,
+            passphrase: password,
+            type: type.substring(0, 3)
         };
 
+        if (type == 'ecc')
+            options.curve = 'ed25519';
+        else if (type == 'rsa4096')
+            options.rsaBits = 4096;
+        else
+            options.rsaBits = 2048;
+
         openpgp.generateKey(options).then(function(keypair) {
             // success
-            var post = {_a: 'import', _keys: keypair.privateKeyArmored, _generated: 1,
-                _passwd: password, _keyid: keypair.key.primaryKey.getFingerprint()};
+            var post = {
+              _a: 'import',
+              _keys: keypair.privateKey,
+              _generated: 1,
+              _passwd: password
+            };
 
             // send request to server
             rcmail.http_post('plugin.enigmakeys', post, lock);
@@ -288,7 +299,7 @@ rcube_webmail.prototype.enigma_export = function(selected)
     this.enigma_export_submit(args);
 };
 
-// Sumbitting request for key(s) export
+// Submitting request for key(s) export
 // Done this way to handle password input
 rcube_webmail.prototype.enigma_export_submit = function(data)
 {
@@ -327,7 +338,7 @@ rcube_webmail.prototype.enigma_import = function()
     }
 };
 
-// Ssearch for key(s) for import
+// Search for key(s) for import
 rcube_webmail.prototype.enigma_import_search = function()
 {
     var form, search;
@@ -540,11 +551,7 @@ rcube_webmail.prototype.enigma_password_request = function(data)
         myprompt = $('<div class="prompt">'),
         myprompt_content = $('<p class="message">')
             .appendTo(myprompt),
-        myprompt_input = $('<input>').attr({type: 'password', size: 30})
-            .keypress(function(e) {
-                if (e.which == 13)
-                    (ref.is_framed() ? window.parent.$ : $)('.ui-dialog-buttonpane button.mainaction:visible').click();
-            })
+        myprompt_input = $('<input>').attr({type: 'password', size: 30, 'data-submit': 'true'})
             .appendTo(myprompt);
 
     data.key = data.keyid;
